<?xml version="1.0" ?><!DOCTYPE TS><TS language="szl" sourcelanguage="en" version="2.1">
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="83"/>
        <location filename="../src/board.cpp" line="872"/>
        <source>Details</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/board.cpp" line="112"/>
        <source>Clear</source>
        <translation>Wysnoż</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="126"/>
        <source>Guess</source>
        <translation>Rozmotlywać</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="156"/>
        <source>Found</source>
        <translation>Nolezione</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="295"/>
        <source>Normal</source>
        <translation>Ajnfachowe</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="295"/>
        <source>Large</source>
        <translation>Srogie</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="314"/>
        <source>Missed</source>
        <translation>Luftniente</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="448"/>
        <source>Error</source>
        <translation>Feler</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="614"/>
        <source>Success</source>
        <translation>Poradzůne</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="614"/>
        <source>Game Over</source>
        <translation>Szlus!</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/board.cpp" line="793"/>
        <source>%1 of %n point(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <location filename="../src/board.cpp" line="795"/>
        <source>3 of %n point(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <location filename="../src/board.cpp" line="797"/>
        <source>2 of %n point(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <location filename="../src/board.cpp" line="799"/>
        <source>1 of %n point(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <location filename="../src/board.cpp" line="801"/>
        <source>0 of %n point(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <location filename="../src/board.cpp" line="805"/>
        <source>%n point(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="881"/>
        <source>The maximum score was calculated from the following thirty words:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <location filename="../src/clock.cpp" line="93"/>
        <source>m:ss</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <location filename="../src/clock.cpp" line="154"/>
        <source>%n guesses(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <location filename="../src/clock.cpp" line="280"/>
        <source>+%1</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <location filename="../src/clock.cpp" line="344"/>
        <source>%n strike(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <location filename="../src/clock.cpp" line="519"/>
        <source>Tanglet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/clock.cpp" line="520"/>
        <source>Classic</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/clock.cpp" line="521"/>
        <source>Refill</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/clock.cpp" line="522"/>
        <source>Stamina</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/clock.cpp" line="523"/>
        <source>Strikeout</source>
        <translation>Sztrofa</translation>
    </message>
    <message>
        <location filename="../src/clock.cpp" line="524"/>
        <source>Allotment</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/clock.cpp" line="525"/>
        <source>Discipline</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/clock.cpp" line="533"/>
        <source>Counts down from 30 seconds and increases on correct guesses.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/clock.cpp" line="534"/>
        <source>Counts down from 3 minutes.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/clock.cpp" line="535"/>
        <source>Counts down from 30 seconds and refills on correct guesses.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/clock.cpp" line="536"/>
        <source>Counts down from 45 seconds and pauses on correct guesses.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/clock.cpp" line="537"/>
        <source>Game ends after 3 incorrect guesses.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/clock.cpp" line="538"/>
        <source>Game ends after 30 guesses.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/clock.cpp" line="539"/>
        <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Generator</name>
    <message>
        <location filename="../src/generator.cpp" line="273"/>
        <source>Unable to read dice from file.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/generator.cpp" line="351"/>
        <source>Unable to read word list from file.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LanguageDialog</name>
    <message>
        <location filename="../src/language_dialog.cpp" line="44"/>
        <source>Board Language</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/language_dialog.cpp" line="67"/>
        <source>Custom</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/language_dialog.cpp" line="75"/>
        <location filename="../src/language_dialog.cpp" line="82"/>
        <source>Choose...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/language_dialog.cpp" line="91"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; These settings will take effect when you start a new game.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/language_dialog.cpp" line="103"/>
        <source>Language:</source>
        <translation>Godka:</translation>
    </message>
    <message>
        <location filename="../src/language_dialog.cpp" line="106"/>
        <source>Dice:</source>
        <translation>Kobel:</translation>
    </message>
    <message>
        <location filename="../src/language_dialog.cpp" line="110"/>
        <source>Word list:</source>
        <translation>Zestawjyńy słůw:</translation>
    </message>
    <message>
        <location filename="../src/language_dialog.cpp" line="114"/>
        <source>Dictionary:</source>
        <translation>Dykcjůnorz:</translation>
    </message>
    <message>
        <location filename="../src/language_dialog.cpp" line="198"/>
        <source>Choose Dice File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/language_dialog.cpp" line="214"/>
        <source>Choose Word List File</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="52"/>
        <source>Select application language:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="55"/>
        <source>&lt;System Language&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="175"/>
        <source>Note</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="175"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="81"/>
        <source>New Game</source>
        <translation>Nowy szpil</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="146"/>
        <source>Amount of Words:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="147"/>
        <source>Minimum Word Length:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="202"/>
        <source>Low</source>
        <translation>Mały</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="203"/>
        <source>Medium</source>
        <translation>Strzedńi</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="204"/>
        <source>High</source>
        <translation>Wjelki</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="205"/>
        <source>Random</source>
        <translation>Cufalym</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/new_game_dialog.cpp" line="222"/>
        <source>%n letter(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <location filename="../src/scores_dialog.cpp" line="52"/>
        <source>High Scores</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/scores_dialog.cpp" line="78"/>
        <source>Name</source>
        <translation>Mjano</translation>
    </message>
    <message>
        <location filename="../src/scores_dialog.cpp" line="79"/>
        <source>Score</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/scores_dialog.cpp" line="80"/>
        <source>Date</source>
        <translation>Datům</translation>
    </message>
    <message>
        <location filename="../src/scores_dialog.cpp" line="81"/>
        <source>Timer</source>
        <translation>Zygor</translation>
    </message>
    <message>
        <location filename="../src/scores_dialog.cpp" line="85"/>
        <source>#%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/scores_dialog.cpp" line="202"/>
        <source>Question</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/scores_dialog.cpp" line="202"/>
        <source>Clear high scores?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/main.cpp" line="33"/>
        <source>Tanglet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="307"/>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Paused&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click to resume playing.&lt;/p&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="313"/>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Loading game...&lt;/p&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="318"/>
        <source>Click to start a new game.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="324"/>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generating a new board...&lt;/p&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="329"/>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizing word list...&lt;/p&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="334"/>
        <source>&amp;Game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="335"/>
        <source>New &amp;Game...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="335"/>
        <source>Ctrl+Shift+N</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="336"/>
        <source>&amp;New Roll</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="337"/>
        <source>&amp;Choose...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="338"/>
        <source>&amp;Share...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="340"/>
        <source>&amp;End</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="343"/>
        <source>&amp;Pause</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="345"/>
        <source>Ctrl+P</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="350"/>
        <source>&amp;Details</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="352"/>
        <source>&amp;High Scores</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="354"/>
        <source>&amp;Quit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="354"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="359"/>
        <source>&amp;Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="360"/>
        <source>Show &amp;Maximum Score</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="362"/>
        <source>&amp;Never</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="363"/>
        <source>&amp;End Of Game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="364"/>
        <source>&amp;Always</source>
        <translation>&amp;Zawdy</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="372"/>
        <source>Show Missed &amp;Words</source>
        <translation>przeboczůne słowa</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="375"/>
        <source>Show Word &amp;Counts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="379"/>
        <source>&amp;Board Language...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="381"/>
        <source>Application &amp;Language...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="385"/>
        <source>&amp;Help</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="386"/>
        <source>&amp;Controls</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="388"/>
        <source>&amp;About</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="390"/>
        <source>About &amp;Hspell</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="392"/>
        <source>About &amp;Qt</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="394"/>
        <source>About &amp;SCOWL</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="553"/>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="551"/>
        <source>Tanglet %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="549"/>
        <source>About</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="552"/>
        <source>A single player variant of &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="554"/>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="555"/>
        <source>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="556"/>
        <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="563"/>
        <source>About Hspell</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="570"/>
        <source>About SCOWL</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="599"/>
        <source>Import Game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="601"/>
        <location filename="../src/window.cpp" line="614"/>
        <source>Tanglet Games (*.tanglet)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="814"/>
        <location filename="../src/window.cpp" line="829"/>
        <source>Unable to start requested game.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="814"/>
        <location filename="../src/window.cpp" line="829"/>
        <source>Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="612"/>
        <source>Export Game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="411"/>
        <location filename="../src/window.cpp" line="659"/>
        <source>Question</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="411"/>
        <location filename="../src/window.cpp" line="659"/>
        <source>End the current game?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="698"/>
        <source>Details</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="704"/>
        <source>Board Size:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="704"/>
        <source>Normal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="704"/>
        <source>Large</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="705"/>
        <source>Word Density:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="706"/>
        <source>Word Length:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="706"/>
        <source>%1 or more letters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="707"/>
        <source>Game Type:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="708"/>
        <source>Description:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="738"/>
        <source>Controls</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/window.cpp" line="738"/>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WordCounts</name>
    <message>
        <location filename="../src/word_counts.cpp" line="41"/>
        <source>Letters:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/word_counts.cpp" line="41"/>
        <source>Found:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/word_counts.cpp" line="117"/>
        <source>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/word_counts.cpp" line="122"/>
        <source>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/word_counts.cpp" line="124"/>
        <source>%1&lt;br&gt;%2/%3</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WordTree</name>
    <message numerus="yes">
        <location filename="../src/word_tree.cpp" line="93"/>
        <source>%n point(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/main.cpp" line="73"/>
        <source>Word finding game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main.cpp" line="76"/>
        <source>A game file to play.</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
